=== modified file 'doc/en/user-guide/organizing_branches.txt'
--- doc/en/user-guide/organizing_branches.txt	2008-07-14 17:26:07 +0000
+++ doc/en/user-guide/organizing_branches.txt	2008-12-24 03:14:16 +0000
@@ -14,9 +14,9 @@
 (or ``checkout``) command to create the mirror.
 For example::
 
-  bzr init-repo X-repo
-  cd X-repo
-  bzr branch sftp://centralhost/srv/bzr/X-repo/X-trunk
+  bzr init-repo PROJECT
+  cd PROJECT
+  bzr branch sftp://centralhost/srv/bzr/PROJECT/trunk
 
 Task branches
 -------------
@@ -28,8 +28,8 @@
 To create a task branch, use the ``branch`` command
 against your mirror branch. For example::
 
-  bzr branch X-trunk X-fix-123
-  cd X-fix-123
+  bzr branch trunk fix-123
+  cd fix-123
   (hack, hack, hack)
 
 There are numerous advantages to this approach:
@@ -51,7 +51,7 @@
 
 Use the ``pull`` command to do this::
 
-  cd X-trunk
+  cd trunk
   bzr pull
 
 Merging the latest trunk into a feature branch
@@ -59,10 +59,10 @@
 
 Use the ``merge`` command to do this::
 
-  cd X-fix-123
+  cd fix-123
   bzr merge
   (resolve any conflicts)
-  bzr commit -m "merged X-trunk"
+  bzr commit -m "merged trunk"
 
 Merging a feature into the trunk
 --------------------------------
@@ -73,17 +73,17 @@
 
 If your mirror is a checkout::
 
-  cd X-trunk
+  cd trunk
   bzr update
-  bzr merge ../X-fix-123
+  bzr merge ../fix-123
   (resolve any conflicts)
   bzr commit -m "Fixed bug #123"
 
 If your mirror is a branch::
 
-  cd X-trunk
+  cd trunk
   bzr pull
-  bzr merge ../X-fix-123
+  bzr merge ../fix-123
   (resolve any conflicts)
   bzr commit -m "Fixed bug #123"
   bzr push

=== modified file 'doc/en/user-guide/publishing_a_branch.txt'
--- doc/en/user-guide/publishing_a_branch.txt	2007-12-14 07:35:49 +0000
+++ doc/en/user-guide/publishing_a_branch.txt	2008-12-24 03:14:16 +0000
@@ -14,7 +14,7 @@
 store history, not working copies of files, so their enclosing
 repository is usually creating using the ``no-trees`` option, e.g.::
 
-  bzr init-repo --no-trees sftp://centralhost/srv/bzr/X-repo/
+  bzr init-repo --no-trees sftp://centralhost/srv/bzr/PROJECT
 
 You can think of this step as similar to setting up a new cvsroot or
 Subversion repository. However, Bazaar gives you more flexibility
@@ -34,25 +34,28 @@
 
 Here is an example of the first way::
 
-  bzr init-repo X-repo
-  bzr init X-repo/X-trunk
-  cd X-repo/X-trunk
-  cp -ar ~/X .     (copy files in using OS-specific tools)
-  bzr add
+  bzr init-repo PROJECT  (prepare local repository)
+  bzr init PROJECT/trunk
+  cd PROJECT/trunk
+			 (copy development files)
+  cp -ar ~/PROJECT .     (copy files in using OS-specific tools)
+  bzr add                (populate repository; start version control)
   bzr commit -m "Initial import"
-  (local branch has content - publish it centrally now)
-  bzr push sftp://centralhost/srv/bzr/X-repo/X-trunk
+                         (publish to central repository)
+  bzr push sftp://centralhost/srv/bzr/PROJECT/trunk
 
 Here is an example of the second way::
 
-  bzr init-repo X-repo
-  cd X-repo
-  bzr init sftp://centralhost/srv/bzr/X-repo/X-trunk
-  bzr checkout sftp://centralhost/srv/bzr/X-repo/X-trunk
-  cd X-trunk
-  cp -ar ~/X .     (copy files in using OS-specific tools)
-  bzr add
+  bzr init-repo PROJECT  (prepare local repository)
+  cd PROJECT
+  bzr init sftp://centralhost/srv/bzr/PROJECT/trunk
+  bzr checkout sftp://centralhost/srv/bzr/PROJECT/trunk
+  cd trunk
+  cp -ar ~/PROJECT .     (copy files in using OS-specific tools)
+  bzr add                (populate repository; start version control)
   bzr commit -m "Initial import"
+                         (publish to central repository)
+  bzr push sftp://centralhost/srv/bzr/project/trunk
 
 Note that committing inside a working tree created using
 the ``checkout`` command implicitly commits the content to

=== modified file 'doc/en/user-guide/reusing_a_checkout.txt'
--- doc/en/user-guide/reusing_a_checkout.txt	2007-12-14 07:35:49 +0000
+++ doc/en/user-guide/reusing_a_checkout.txt	2008-12-24 03:14:16 +0000
@@ -61,24 +61,24 @@
 with a local tree-less repository. This lets you switch what you
 are working on with ease. For example::
 
-  bzr init-repo --no-trees X-repo
-  cd X-repo
-  bzr branch sftp://centralhost/srv/bzr/X-repo/X-trunk
-  bzr checkout --lightweight X-trunk my-sandbox
+  bzr init-repo --no-trees PROJECT
+  cd PROJECT
+  bzr branch sftp://centralhost/srv/bzr/PROJECT/trunk
+  bzr checkout --lightweight trunk my-sandbox
   cd my-sandbox
   (hack away)
 
-Note that X-trunk in this example will have a ``.bzr`` directory within it
+Note that trunk in this example will have a ``.bzr`` directory within it
 but there will be no working tree there as the branch was created in
 a tree-less repository. You can grab or create as many branches as you
 need there and switch between them as required. For example::
 
   (assuming in my-sandbox)
-  bzr branch sftp://centralhost/srv/bzr/X-repo/X-1.0 ../X-1.0
-  bzr switch ../X-1.0
+  bzr branch sftp://centralhost/srv/bzr/PROJECT/PROJECT-1.0 ../PROJECT-1.0
+  bzr switch ../PROJECT-1.0
   (fix bug in 1.0)
   bzr commit -m "blah, blah blah"
-  bzr switch ../X-trunk
+  bzr switch ../trunk
   (go back to working on the trunk)
 
 Note: The branches may be local only or they may be bound to

=== modified file 'doc/en/user-guide/using_checkouts.txt'
--- doc/en/user-guide/using_checkouts.txt	2008-10-16 10:57:16 +0000
+++ doc/en/user-guide/using_checkouts.txt	2008-12-24 03:14:16 +0000
@@ -7,7 +7,7 @@
 If you have a local branch and wish to make it a checkout, use the
 ``bind`` command like this::
 
-  bzr bind sftp://centralhost/srv/bzr/X-repo/X-trunk
+  bzr bind sftp://centralhost/srv/bzr/PROJECT/trunk
 
 This is necessary, for example, after creating a central branch using
 ``push`` as illustrated in the previous section.
@@ -56,7 +56,7 @@
 To get a history-less checkout in Bazaar, use the ``--lightweight``
 option like this::
 
-  bzr checkout --lightweight sftp://centralhost/srv/bzr/X-repo/X-trunk
+  bzr checkout --lightweight sftp://centralhost/srv/bzr/PROJECT/trunk
 
 Of course, many of the benefits of a normal checkout are lost by doing
 this but that's a tradeoff you can make if and when it makes sense.

